@@ -67,22 +67,23 @@ define([
         this.uuid = uuid;   // Load html 영역의 uuid.
         // Import 기본 패키지 목록
         this.packageList = [
-            { library:'numpy',     alias:'np'}
-            , { library:'pandas',  alias:'pd'}
+            { library: 'numpy',     alias:'np'}
+            , { library: 'pandas',  alias:'pd'}
             , { 
-                library:'matplotlib.pyplot', alias:'plt' 
+                library: 'matplotlib.pyplot', alias:'plt' 
                 , include: [
                     '%matplotlib inline'
                 ]
             }
-            , { library:'seaborn', alias:'sns'}
+            , { library: 'seaborn', alias:'sns'}
+            , { library: 'plotly.express', alias: 'px'}
         ];
         
         this.package = {
             id: 'import',
             name: 'import package',
             library: 'common',
-            description: '공통 패키지 임포트',
+            description: 'import basic packages',
             code: '',
             input: [
                 {
@@ -118,7 +119,7 @@ define([
      * html 내부 binding 처리
      */
     ImportPackage.prototype.initHtml = function() {
-        this.bindImportPackageGrid();
+        this.bindEvent();
 
         // if need additional css
         // this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.SOURCE_PATH + "file_io/test.css");
@@ -127,7 +128,7 @@ define([
     /**
      * Import 기본 패키지 바인딩
      */
-    ImportPackage.prototype.bindImportPackageGrid = function() {
+    ImportPackage.prototype.bindEvent = function() {
         var that = this;
 
 
@@ -135,9 +136,10 @@ define([
             try {
                 var importMeta = JSON.parse(decodeURIComponent(this.metadata.options.find(x=>x.id=='vp_importMeta').value));
                 importMeta && importMeta.forEach((obj, i) => {
-                    var tagTr = $(`<tr><td><input id="vp_library${i}" type="text" class="vp-input m vp-add-library" placeholder="library name" required value="${obj.library.toLowerCase()}"/></td>
-                    <td><input id="vp_alias${i}" type="text" class="vp-input m vp-add-alias" placeholder="as" value="${obj.alias}"/></td>
-                    <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
+                    // var tagTr = $(`<tr><td><input id="vp_library${i}" type="text" class="vp-input m vp-add-library" placeholder="library name" required value="${obj.library.toLowerCase()}"/></td>
+                    // <td><input id="vp_alias${i}" type="text" class="vp-input m vp-add-alias" placeholder="as" value="${obj.alias}"/></td>
+                    // <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
+                    var tagTr = $(that.renderLibraryRow(i, obj.library.toLowerCase(), obj.alias));
                 
                     $(this.wrapSelector("#vp_tblImport tr:last")).before(tagTr);
                 });
@@ -148,10 +150,11 @@ define([
                 //         <option value="as">as</option>
                 //         <option value="import">import</option>
                 //     </select>
-                var tagTr = $(`<tr><td><input id="vp_library${i}" type="text" class="vp-input m vp-add-library" placeholder="library name" required value="${package.library.toLowerCase()}"/></td>
-                <td><input id="vp_alias${i}" type="text" class="vp-input m vp-add-alias" placeholder="as" value="${package.alias}"/></td>
-                <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
-            
+                // var tagTr = $(`<tr><td><input id="vp_library${i}" type="text" class="vp-input m vp-add-library" placeholder="library name" required value="${package.library.toLowerCase()}"/></td>
+                // <td><input id="vp_alias${i}" type="text" class="vp-input m vp-add-alias" placeholder="as" value="${package.alias}"/></td>
+                // <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
+                var tagTr = $(that.renderLibraryRow(i, package.library.toLowerCase(), package.alias));
+
                 $(this.wrapSelector("#vp_tblImport tr:last")).before(tagTr);
     
                 // add to package input
@@ -162,15 +165,18 @@ define([
 
         // 라이브러리 삭제
         $(document).on("click", this.wrapSelector('.vp-remove-option'), function() {
-             // X 버튼과 동일한 행 삭제
+             // X 아이콘과 동일한 행 삭제
              $(this).closest('tr').remove();
         });
 
         // 라이브러리 추가
         $(this.wrapSelector('#vp_addLibrary')).click(function() {
-            var tagTr = $(`<tr><td><input type="text" class="vp-add-library" placeholder="library name" required/></td>
-            <td><input type="text" class="vp-input m vp-add-alias" placeholder="alias"/></td>
-            <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
+            var libsLength = $(that.wrapSelector("#vp_tblImport tr:not(:first):not(:last)")).length;
+
+            // var tagTr = $(`<tr><td><input type="text" class="vp-add-library" placeholder="library name" required/></td>
+            // <td><input type="text" class="vp-input m vp-add-alias" placeholder="alias"/></td>
+            // <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>`);
+            var tagTr = $(that.renderLibraryRow(libsLength, '', ''));
 
             $(that.wrapSelector("#vp_tblImport tr:last")).before(tagTr);
         });
@@ -195,6 +201,23 @@ define([
         
     }
 
+    ImportPackage.prototype.renderLibraryRow = function(idx, libraryName, aliasName) {
+        var tag = new sb.StringBuilder();
+        /**
+         * <td><input id="vp_library${i}" type="text" class="vp-input m vp-add-library" placeholder="library name" required value="${package.library.toLowerCase()}"/></td>
+                <td><input id="vp_alias${i}" type="text" class="vp-input m vp-add-alias" placeholder="as" value="${package.alias}"/></td>
+                <td><input type="button" class="vp-remove-option w100" style="width:100%;" value="x"></td></tr>
+         */
+        tag.append('<tr>');
+        tag.appendFormat('<td><input id="{0}" type="text" class="{1}" placeholder="{2}" required value="{3}"/></td>'
+                        , 'vp_library' + idx, 'vp-input m vp-add-library', 'Type library name', libraryName);
+        tag.appendFormat('<td><input id="{0}" type="text" class="{1}" placeholder="{2}" value="{3}"/></td>'
+                        , 'vp_alias' + idx, 'vp-input m vp-add-alias', 'Type alias', aliasName);
+        tag.appendFormat('<td class="{0}"><img src="{1}"/></td>', 'vp-remove-option w100 vp-cursor', '/nbextensions/visualpython/resource/close_small.svg');
+        tag.append('</tr>');
+        return tag.toString();
+    }
+
     /**
      * 코드 생성
      * @param {boolean} addCell 셀 추가 여부
